pub enum MultiedgePolicy {
ErrorOnMultiedge,
KeepFirst,
KeepLast,
MinWeight,
SumWeight,
CountEdges,
}Expand description
How to collapse parallel edges between the same endpoints into one cell.
Variants
ErrorOnMultiedge
Fail if any pair has more than one edge.
KeepFirst
Keep the first edge (by edge id) for each pair.
KeepLast
Keep the last edge (by edge id) for each pair.
MinWeight
Keep the minimum weight for each pair.
SumWeight
Sum the weights for each pair.
CountEdges
Use the number of parallel edges as the cell value.