Module control

Module control 

Work, memory, deadline, and cancellation control for graph algorithms.

Structs

AlgorithmControl
Bounds and accounting policy for a graph algorithm run.
AlgorithmReceipt
Deterministic accounting evidence returned by a completed algorithm.
AlgorithmWorkCosts
Work charged for one dynamic-programming cell and one examined edge.
NeverInterrupt
Cancellation source that never interrupts.

Traits

AlgorithmInterrupt
Cooperative cancellation source for graph algorithms.