Module traversal

Module traversal 

Deterministic breadth-first and depth-first traversal.

Structs

Traversal
The result of a traversal from a single start node.

Functions

bfs
Breadth-first traversal from start. Neighbors are visited in ascending node order, so the result is deterministic.
dfs
Depth-first traversal from start. Neighbors are explored in ascending node order, so the result is deterministic.