Work, memory, deadline, and cancellation control for graph algorithms.
Structs
- Algorithm
Control - Bounds and accounting policy for a graph algorithm run.
- Algorithm
Receipt - Deterministic accounting evidence returned by a completed algorithm.
- Algorithm
Work Costs - Work charged for one dynamic-programming cell and one examined edge.
- Never
Interrupt - Cancellation source that never interrupts.
Traits
- Algorithm
Interrupt - Cooperative cancellation source for graph algorithms.