Module traversal
sim_
lib_
discrete_
graph
0.2.0
Module traversal
Module Items
Structs
Functions
In crate sim_
lib_
discrete_
graph
sim_lib_discrete_graph
Module
traversal
Deterministic breadth-first and depth-first traversal.
Structs

Traversal
The result of a traversal from a single start node.
Functions

bfs
Breadth-first traversal from
start
. Neighbors are visited in ascending node order, so the result is deterministic.
dfs
Depth-first traversal from
start
. Neighbors are explored in ascending node order, so the result is deterministic.